import subprocess
import requests
from diz.utils import validators
import os
import tempfile


def run_command_in_venv(command, venv_path):
    activate_script = f"{venv_path}/bin/activate"
    cmd = f"source {activate_script} && {command}"
    subprocess.run(cmd, shell=True)


def install(dep, venv_path):
    if validators.is_valid_url(dep):
        install_from_url(dep, venv_path)
    else:
        run_command_in_venv(f"pip install {dep}", venv_path)


def install_from_url(url, ven_path):
    with tempfile.TemporaryDirectory() as (tmp_dir):
        tmp_file = os.path.join(tmp_dir, 'requirements.txt')
        with open(tmp_file, 'w') as (f):
            f.write(requests.get(url).text)
        run_command_in_venv(f"pip install -r {tmp_file}", ven_path)


import yaml
import requests
from diz.utils import validators


def load_yaml(path):
    if validators.is_valid_url(path):
        return load_yaml_with_url(path)
    with open(path, 'r') as (f):
        return yaml.safe_load(f)


def load_yaml_with_url(url):
    return yaml.safe_load(requests.get(url).text)


import os.path
import git
import diz.utils.dir
from diz.utils import pip
from diz.utils import download, yaml
from toolz import pipe


class SetupCommand:
    def __init__(self, pkg: str, path: str):
        self.pkg = pkg
        self.path = path
        self.config = yaml.load_yaml(self.pkg)
        self.install_path = self.path

    def create_dir(self, path, print_path=True):
        target_path = pipe(
            path,
            lambda p: os.path.join(self.install_path, p),
            os.path.expanduser,
        )
        if not os.path.exists(target_path):
            os.makedirs(target_path)
        if print_path:
            print(f"创建目录：{target_path}")
        return target_path

    def get_dir(self, path):
        target_path = pipe(
            path,
            lambda p: os.path.join(self.install_path, p),
            os.path.expanduser,
        )
        return target_path

    def clone_code(self):
        if diz.utils.dir.is_empty(self.create_dir("code", False)):
            git.Repo.clone_from(self.config['code_repo'], self.create_dir("code", False))
            print("下载完成！")
        else:
            print("已经下载过了，无需下载。")

    def download_model_from_huggingface(self):
        if diz.utils.dir.is_empty(self.create_dir("model", False)):
            download.save_huggingface_model(self.config['huggingface'], self.create_dir("model", False))
            print("下载完成！")
        else:
            print("已经下载过了，无需下载。")

    def create_venv(self):
        if diz.utils.dir.is_empty(self.create_dir("venv", False)):
            os.system(f"cd {self.path} && python -m venv venv")
            print("创建虚拟环境完成！")

    def install_deps(self):
        venv_path = self.get_dir("venv")
        for dep in self.config['deps']:
            pip.install(dep, venv_path)

    def run(self):
        self.create_dir("code")
        self.create_dir("model")
        self.clone_code()
        self.download_model_from_huggingface()
        self.create_venv()
        self.install_deps()



import typer
import subprocess
from diz.commands.setup import SetupCommand
from typing_extensions import Annotated


app = typer.Typer()


@app.command()
def setup(path: Annotated[str, typer.Option(prompt="请输入安装目录")],
          pkg: Annotated[str, typer.Option(prompt="请输入配置文件的 URL 地址")]):
    SetupCommand(path=path, pkg=pkg).run()


@app.command()
def gpu_info():
    try:
        info = subprocess.check_output(['nvidia-smi'], universal_newlines=True)
        print(info)
    except FileNotFoundError:
        print('nvidia-smi command not found. Make sure NVIDIA drivers are installed.')
    except subprocess.CalledProcessError:
        print('Not connected to a GPU')


def main():
    app()


if __name__ == "__main__":
    main()



from setuptools import setup, find_packages


def readme():
    with open('README.md', 'r') as f:
        return f.read()


setup(
    name='diz',
    version='0.0.7',
    author='mjason',
    description='用来构建大模型环境的工具',
    long_description=readme(),
    long_description_content_type='text/markdown',
    packages=find_packages(),
    install_requires=[
        'GitPython>=3.1.31',
        'huggingface-hub>=0.16.4',
        'PyYAML>=6.0',
        'requests>=2.31.0',
        'toolz>=0.12.0',
        'typer>=0.9.0'
    ],
    entry_points={
        'console_scripts': [
            'diz = diz.main:main'
        ]
    }
)